==> fred_regal-2.0.0.tar.gz: fred_regal-2.0.0/regal/__init__.py <==
"""Registry auxiliary library."""
# flake8: noqa: F401 - ignore unused imports

from warnings import warn

from fred_types import (
    ContactHistoryId as ContactHistoryId_,
    ContactId as ContactId_,
    ContactRef as ContactRef_,
    DomainHistoryId as DomainHistoryId_,
    DomainId as DomainId_,
    DomainRef as DomainRef_,
    KeysetHistoryId as KeysetHistoryId_,
    KeysetId as KeysetId_,
    KeysetRef as KeysetRef_,
    NssetHistoryId as NssetHistoryId_,
    NssetId as NssetId_,
    NssetRef as NssetRef_,
)

from .common import Address, FileId, FuzzyValue, ObjectEvent, ObjectEvents
from .contact import AdditionalIdentifier, Contact, ContactClient, ContactIdentifierType, WarningLetterPreference
from .domain import Domain, DomainAdminClient, DomainClient, DomainContactRole, DomainLifeCycleStage, NotDeletedReason
from .domain_blacklist import Block, BlockId, BlockRef, DomainBlacklistClient
from .keyset import DnsKey, Keyset, KeysetClient
from .nsset import DnsHost, Nsset, NssetClient
from .registrar import (
    Registrar,
    RegistrarAdminClient,
    RegistrarCertification,
    RegistrarCertificationId,
    RegistrarClient,
)
from .representative import Representative, RepresentativeClient
from .search import SearchContactClient, SearchDomainClient, SearchKeysetClient, SearchNssetClient, SearchResults

__version__ = "2.0.0"

__all__ = [
    "AdditionalIdentifier",
    "Address",
    "Block",
    "BlockId",
    "BlockRef",
    "Contact",
    "ContactClient",
    "ContactIdentifierType",
    "DnsHost",
    "DnsKey",
    "Domain",
    "DomainAdminClient",
    "DomainBlacklistClient",
    "DomainClient",
    "DomainContactRole",
    "DomainLifeCycleStage",
    "FileId",
    "FuzzyValue",
    "Keyset",
    "KeysetClient",
    "NotDeletedReason",
    "Nsset",
    "NssetClient",
    "ObjectEvent",
    "ObjectEvents",
    "Registrar",
    "RegistrarAdminClient",
    "RegistrarCertification",
    "RegistrarCertificationId",
    "RegistrarClient",
    "Representative",
    "RepresentativeClient",
    "RepresentativeHistoryId",
    "RepresentativeId",
    "SearchContactClient",
    "SearchDomainClient",
    "SearchKeysetClient",
    "SearchNssetClient",
    "SearchResults",
    "WarningLetterPreference",
    # Deprecated types
    "ContactHistoryId",
    "ContactId",
    "ContactRef",
    "DomainHistoryId",
    "DomainId",
    "DomainRef",
    "KeysetHistoryId",
    "KeysetId",
    "KeysetRef",
    "NssetHistoryId",
    "NssetId",
    "NssetRef",
]

#: Objects in this list should be directly imported from 'fred-types' package
_regal_deprecated = [
    "ContactHistoryId",
    "ContactId",
    "ContactRef",
    "DomainHistoryId",
    "DomainId",
    "DomainRef",
    "KeysetHistoryId",
    "KeysetId",
    "KeysetRef",
    "NssetHistoryId",
    "NssetId",
    "NssetRef",
]


def __getattr__(name):  # type: ignore [no-untyped-def]
    if name in _regal_deprecated:  # pragma: nocover
        warn(f"'{name}' should be imported directly from 'fred-types'", DeprecationWarning, stacklevel=2)
        return globals()[f"{name}_"]
    raise AttributeError(f"module '{__name__!r}' has no attribute '{name!r}'")

==> fred_regal-2.1.0.tar.gz: fred_regal-2.1.0/regal/__init__.py <==
"""Registry auxiliary library."""
# flake8: noqa: F401 - ignore unused imports

from warnings import warn

from fred_types import (
    ContactHistoryId as ContactHistoryId_,
    ContactId as ContactId_,
    ContactRef as ContactRef_,
    DomainHistoryId as DomainHistoryId_,
    DomainId as DomainId_,
    DomainRef as DomainRef_,
    KeysetHistoryId as KeysetHistoryId_,
    KeysetId as KeysetId_,
    KeysetRef as KeysetRef_,
    NssetHistoryId as NssetHistoryId_,
    NssetId as NssetId_,
    NssetRef as NssetRef_,
)

from .common import Address, FileId, FuzzyValue, ListPage, ObjectEvent, ObjectEvents, PaginationReply
from .contact import AdditionalIdentifier, Contact, ContactClient, ContactIdentifierType, WarningLetterPreference
from .domain import Domain, DomainAdminClient, DomainClient, DomainContactRole, DomainLifeCycleStage, NotDeletedReason
from .domain_blacklist import Block, BlockId, BlockRef, DomainBlacklistClient
from .keyset import DnsKey, DSRecord, Keyset, KeysetClient
from .nsset import DnsHost, Nsset, NssetClient
from .registrar import (
    Registrar,
    RegistrarAdminClient,
    RegistrarCertification,
    RegistrarCertificationId,
    RegistrarClient,
)
from .representative import Representative, RepresentativeClient
from .search import SearchContactClient, SearchDomainClient, SearchKeysetClient, SearchNssetClient, SearchResults

__version__ = "2.1.0"

__all__ = [
    "AdditionalIdentifier",
    "Address",
    "Block",
    "BlockId",
    "BlockRef",
    "Contact",
    "ContactClient",
    "ContactIdentifierType",
    "DnsHost",
    "DnsKey",
    "Domain",
    "DomainAdminClient",
    "DomainBlacklistClient",
    "DomainClient",
    "DomainContactRole",
    "DomainLifeCycleStage",
    "DSRecord",
    "FileId",
    "FuzzyValue",
    "Keyset",
    "KeysetClient",
    "ListPage",
    "NotDeletedReason",
    "Nsset",
    "NssetClient",
    "ObjectEvent",
    "ObjectEvents",
    "PaginationReply",
    "Registrar",
    "RegistrarAdminClient",
    "RegistrarCertification",
    "RegistrarCertificationId",
    "RegistrarClient",
    "Representative",
    "RepresentativeClient",
    "RepresentativeHistoryId",
    "RepresentativeId",
    "SearchContactClient",
    "SearchDomainClient",
    "SearchKeysetClient",
    "SearchNssetClient",
    "SearchResults",
    "WarningLetterPreference",
    # Deprecated types
    "ContactHistoryId",
    "ContactId",
    "ContactRef",
    "DomainHistoryId",
    "DomainId",
    "DomainRef",
    "KeysetHistoryId",
    "KeysetId",
    "KeysetRef",
    "NssetHistoryId",
    "NssetId",
    "NssetRef",
]

#: Objects in this list should be directly imported from 'fred-types' package
_regal_deprecated = [
    "ContactHistoryId",
    "ContactId",
    "ContactRef",
    "DomainHistoryId",
    "DomainId",
    "DomainRef",
    "KeysetHistoryId",
    "KeysetId",
    "KeysetRef",
    "NssetHistoryId",
    "NssetId",
    "NssetRef",
]


def __getattr__(name):  # type: ignore [no-untyped-def]
    if name in _regal_deprecated:  # pragma: nocover
        warn(f"'{name}' should be imported directly from 'fred-types'", DeprecationWarning, stacklevel=2)
        return globals()[f"{name}_"]
    raise AttributeError(f"module '{__name__!r}' has no attribute '{name!r}'")
